==> gnome-shell-extension-gtk4-desktop-icons-ng-1:100.12-1-any.pkg.tar.zst: usr/share/gnome-shell/extensions/gtk4-ding@smedius.gitlab.com/dependencies/localFiles.js <==
export {DesktopFolderUtils} from '../app/utils/desktopFolderUtils.js';
export * as AdwPreferencesWindow from '../app/adwPreferencesWindow.js';
export * as AppChooser from '../app/appChooser.js';
export * as AskRenamePopup from '../app/askRenamePopup.js';
export * as AutoAr from '../app/autoAr.js';
export * as DBusInterfaces from '../app/utils/dbusInterfaces.js';
export * as DBusUtils from '../app/utils/dbusUtils.js';
export * as DesktopGrid from '../app/desktopGrid.js';
export * as DesktopIconsUtil from '../app/utils/desktopIconsUtil.js';
export * as DesktopManager from '../app/desktopManager.js';
export * as DesktopMonitor from '../app/desktopFolderMonitor.js';
export * as Enums from '../app/enums.js';
export * as FileItemMenu from '../app/fileItemMenu.js';
export * as FileUtils from '../utils/fileUtils.js';
export * as Preferences from '../app/preferences.js';
export * as GnomeShellDragDrop from '../app/gnomeShellDragDrop.js';
export * as GsConnect from '../app/utils/gsConnect.js';
export * as ShowErrorPopup from '../app/showErrorPopup.js';
export * as StackItem from '../app/stackItem.js';
export * as TemplatesScriptsManager from '../app/templatesScriptsManager.js';
export * as Thumbnails from '../app/thumbnails.js';
export * as WindowManager from '../app/windowManager.js';
export * as DesktopMenu from '../app/desktopMenu.js';
export * as DragManager from '../app/dragManager.js';
export {IconCreator} from '../app/desktopIconFactory.js';
export {FileItemIcon} from '../app/fileItemIcon.js';
export {DesktopIconItem} from '../app/desktopIconItem.js';
export {VolumeIcon} from '../app/volumeIcon.js';
export {DesktopFileIcon} from '../app/desktopFileIcon.js';
export {AppImageFileIcon} from '../app/appImageFileItem.js';
export {SymLinkIcon} from '../app/symLinkIcon.js';
export {SpecialFolderIcon} from '../app/specialFolderIcon.js';
export {ShortcutManager} from '../app/shortcutManager.js';
export {DefaultShortcuts} from '../app/shortcuts.js';
export {GlobalShortcuts} from '../app/shortcuts.js';
export * as WidgetManager from '../app/widgetManager.js';
export {WidgetRegistry} from '../app/widgetRegistry.js';
export {HtmlWidgetHost} from '../app/htmlWidgetHost.js';
export * as WidgetApi from '../app/widgetApi.js';
export {FallbackHtml} from '../app/fallbackHtml.js';
export {WebWidgetContext} from '../app/widgetWebContext.js';

==> gnome-shell-extension-gtk4-desktop-icons-ng-1:100.17-1-any.pkg.tar.zst: usr/share/gnome-shell/extensions/gtk4-ding@smedius.gitlab.com/dependencies/localFiles.js <==
export {DesktopFolderUtils} from '../app/utils/desktopFolderUtils.js';
export * as AdwPreferencesWindow from '../app/adwPreferencesWindow.js';
export * as AppChooser from '../app/appChooser.js';
export * as AskRenamePopup from '../app/askRenamePopup.js';
export * as AutoAr from '../app/autoAr.js';
export * as DBusInterfaces from '../app/utils/dbusInterfaces.js';
export * as DBusUtils from '../app/utils/dbusUtils.js';
export * as DesktopGrid from '../app/desktopGrid.js';
export * as DesktopIconsUtil from '../app/utils/desktopIconsUtil.js';
export * as DesktopManager from '../app/desktopManager.js';
export * as DesktopMonitor from '../app/desktopFolderMonitor.js';
export * as Enums from '../app/enums.js';
export * as FileItemMenu from '../app/fileItemMenu.js';
export * as FileUtils from '../utils/fileUtils.js';
export * as Preferences from '../app/preferences.js';
export * as GnomeShellDragDrop from '../app/gnomeShellDragDrop.js';
export * as GsConnect from '../app/utils/gsConnect.js';
export * as ShowErrorPopup from '../app/showErrorPopup.js';
export * as StackItem from '../app/stackItem.js';
export * as TemplatesScriptsManager from '../app/templatesScriptsManager.js';
export * as Thumbnails from '../app/thumbnails.js';
export * as WindowManager from '../app/windowManager.js';
export * as DesktopMenu from '../app/desktopMenu.js';
export * as DragManager from '../app/dragManager.js';
export {IconCreator} from '../app/desktopIconFactory.js';
export {FileItemIcon} from '../app/fileItemIcon.js';
export {DesktopIconItem} from '../app/desktopIconItem.js';
export {VolumeIcon} from '../app/volumeIcon.js';
export {DesktopFileIcon} from '../app/desktopFileIcon.js';
export {AppImageFileIcon} from '../app/appImageFileItem.js';
export {SymLinkIcon} from '../app/symLinkIcon.js';
export {SpecialFolderIcon} from '../app/specialFolderIcon.js';
export {ShortcutManager} from '../app/shortcutManager.js';
export {DefaultShortcuts} from '../app/shortcuts.js';
export {GlobalShortcuts} from '../app/shortcuts.js';
export * as WidgetManager from '../app/widgetManager.js';
export {WidgetRegistry} from '../app/widgetRegistry.js';
export {HtmlWidgetHost} from '../app/htmlWidgetHost.js';
export {HtmlWidgetHostWithBackend} from '../app/htmlWidgetHostWithBackend.js';
export * as WidgetApi from '../app/widgetApi.js';
export {WebWidgetContext} from '../app/widgetWebContext.js';
